@@ -316,118 +316,6 @@ func Test_regexpCompile(t *testing.T) {
 	}
 }
 
-func Test_rangePosition(t *testing.T) {
-	type args struct {
-		s      string
-		substr string
-		number int
-	}
-	tests := []struct {
-		name  string
-		args  args
-		wantS int
-		wantE int
-	}{
-		{
-			name:  "testNil",
-			args:  args{},
-			wantS: 0,
-			wantE: 0,
-		},
-		{
-			name: "test1",
-			args: args{
-				s:      "test",
-				substr: "t",
-				number: 0,
-			},
-			wantS: 1,
-			wantE: 3,
-		},
-		{
-			name: "test2",
-			args: args{
-				s:      "test",
-				substr: "t",
-				number: 1,
-			},
-			wantS: 4,
-			wantE: 4,
-		},
-		{
-			name: "testComma",
-			args: args{
-				s:      "a,b,c",
-				substr: ",",
-				number: 1,
-			},
-			wantS: 2,
-			wantE: 3,
-		},
-		{
-			name: "testVerticalBar",
-			args: args{
-				s:      "a|b|c",
-				substr: "|",
-				number: 2,
-			},
-			wantS: 4,
-			wantE: 5,
-		},
-		{
-			name: "testUnicodeBar",
-			args: args{
-				s:      "a│b│c",
-				substr: "│",
-				number: 1,
-			},
-			wantS: 4,
-			wantE: 5,
-		},
-		{
-			name: "testUnicodeBar2",
-			args: args{
-				s:      "a│b│c",
-				substr: "│",
-				number: 2,
-			},
-			wantS: 8,
-			wantE: 9,
-		},
-		{
-			name: "testUnicodeBar3",
-			args: args{
-				s:      "a│b│c",
-				substr: "│",
-				number: 3,
-			},
-			wantS: -1,
-			wantE: -1,
-		},
-		{
-			name: "testNone",
-			args: args{
-				s:      "a│b│c",
-				substr: "│",
-				number: 9,
-			},
-			wantS: -1,
-			wantE: -1,
-		},
-	}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			gotS, gotE := rangePosition(tt.args.s, tt.args.substr, tt.args.number)
-			if gotS != tt.wantS {
-				t.Errorf("rangePosition() got = %v, want %v", gotS, tt.wantS)
-			}
-			if gotE != tt.wantE {
-				t.Errorf("rangePosition() got1 = %v, want %v", gotE, tt.wantE)
-			}
-		})
-	}
-}
-
 func Test_searchPositionReg(t *testing.T) {
 	type args struct {
 		s  string
