@@ -1,6 +1,8 @@
 package oviewer
 
 import (
+	"strings"
+
 	"golang.org/x/exp/constraints"
 )
 
@@ -50,3 +52,18 @@ func toLast(list []string, s string) []string {
 	list = append(list, s)
 	return list
 }
+
+// allIndex returns all matching string positions.
+func allIndex(s string, substr string) [][]int {
+	if len(substr) == 0 {
+		return nil
+	}
+	var result [][]int
+	for pos, offSet := strings.Index(s, substr), 0; pos != -1; {
+		s = s[pos+len(substr):]
+		result = append(result, []int{pos + offSet, pos + offSet + len(substr)})
+		offSet += pos + len(substr)
+		pos = strings.Index(s, substr)
+	}
+	return result
+}
